# Q_learning_utils
**用于Q-learning的学习,内含MDP环境和Q-learning决策大脑**

代码是根据莫凡Q-leaning教学视频修改而来

👍 在这感谢莫凡的工作！！！👍 

附莫凡Q-learing学习网址：
https://mofanpy.com/tutorials/machine-learning/reinforcement-learning/intro-q-learning/

## 安装
这是安装到pip仓库的方法,可以当作第三方库使用

仅学习——**不需安装，仅克隆**
1. 克隆到本地
    ```shell
    git clone https://github.com/353055619/Q_learning_utils.git
    ```
2. cd到项目文件夹下
    ```shell
    python ./setup install
    ```
## 使用
**main.py是使用示例**
1. 项目文件下运行
   ```shell
   python ./tests/test.py
   ``` 
## 学习
> 请看__init__.py和同级的py文件，注释详细

